@@ -50,7 +50,7 @@ impl Serialize for Literal {
                     Literal::String(l) => (
                         &l.base,
                         AcornLiteralValue::String(l.value.clone()),
-                        Cow::Borrowed(&*l.value),
+                        Cow::Owned(l.raw.to_string()),
                     ),
                     Literal::Numeric(l) => (
                         &l.base,
@@ -182,6 +182,7 @@ pub struct StringLiteral {
     #[serde(flatten)]
     pub base: BaseNode,
     pub value: JsWord,
+    pub raw: JsWord,
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
@@ -316,6 +317,8 @@ pub struct BigIntLiteral {
     pub base: BaseNode,
     #[serde(default)]
     pub value: String,
+    #[serde(default)]
+    pub raw: JsWord,
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
