@@ -324,7 +324,7 @@ pub struct TSIndexSignature {
     #[serde(flatten)]
     pub base: BaseNode,
     #[serde(default)]
-    pub paramters: Vec<Identifier>,
+    pub parameters: Vec<Identifier>,
     #[serde(default)]
     pub type_annotation: Option<Box<TSTypeAnnotation>>,
     #[serde(default)]
@@ -915,4 +915,9 @@ pub struct TSTypeParameter {
     pub default: Option<Box<TSType>>,
     #[serde(default)]
     pub name: JsWord,
+
+    #[serde(default, rename = "in")]
+    pub is_in: bool,
+    #[serde(default, rename = "out")]
+    pub is_out: bool,
 }
